@@ -32,7 +32,7 @@ extern "C" {
  * 0.2.6-1 => 0x00020601
  * 4.5.2-0 => 0x04050200
  */
-#define EXTRACTOR_VERSION 0x00051801
+#define EXTRACTOR_VERSION 0x00052000
 
 #include <stdio.h>
 
@@ -184,7 +184,10 @@ typedef enum {
   EXTRACTOR_STARTING_SONG = 128,
   EXTRACTOR_HARDWARE_DEPENDENCY = 129,
   EXTRACTOR_RIPPER = 130,
-  EXTRACTOR_FILE_SIZE = 131
+  EXTRACTOR_FILE_SIZE = 131,
+  EXTRACTOR_TRACK_NUMBER = 132,
+  EXTRACTOR_ISRC = 133,
+  EXTRACTOR_DISC_NUMBER = 134,
 } EXTRACTOR_KeywordType;
 
 /**
