@@ -172,12 +172,15 @@ static const char *keywordTypes[] = {
   gettext_noop("starting song"),
   gettext_noop("hardware dependency"),
   gettext_noop("ripper"), /* 130 */
-  gettext_noop("filesize") /* 131 */,
+  gettext_noop("filesize"),
+  gettext_noop("track number"),
+  gettext_noop("international standard recording code"),
+  gettext_noop("disc number"), /* 134 */
   NULL,
 };
 
 /* the number of keyword types (for bounds-checking) */
-#define HIGHEST_TYPE_NUMBER 132
+#define HIGHEST_TYPE_NUMBER 135
 
 #ifdef HAVE_LIBOGG
 #if HAVE_VORBIS
@@ -201,6 +204,12 @@ static const char *keywordTypes[] = {
 #define OGGSO ""
 #endif
 
+#if HAVE_FLAC
+#define FLACSO "libextractor_flac:"
+#else
+#define FLACSO ""
+#endif
+
 #if HAVE_ZLIB
 #define QTSO "libextractor_qt:"
 #else
@@ -238,12 +247,14 @@ libextractor_deb:\
 libextractor_png:\
 libextractor_gif:\
 libextractor_wav:\
+libextractor_flv:\
 libextractor_real:\
 libextractor_jpeg:\
 libextractor_tiff:\
 libextractor_zip:\
 libextractor_rpm:\
 libextractor_riff:\
+libextractor_applefile:\
 libextractor_elf:\
 libextractor_oo:\
 libextractor_asf:\
@@ -251,7 +262,7 @@ libextractor_sid:\
 libextractor_nsfe:\
 libextractor_nsf"
 
-#define DEFAULT_LIBRARIES MPEGSO EXSO OLESO OGGSO QTSO DEFSO
+#define DEFAULT_LIBRARIES MPEGSO EXSO OLESO OGGSO FLACSO QTSO DEFSO
 
 const char * EXTRACTOR_getDefaultLibraries() {
   return DEFAULT_LIBRARIES;
@@ -329,16 +340,16 @@ get_path_from_proc_exe() {
 			   "libextractor")) ) {
 	strstr(dir, "libextractor")[0] = '\0';
 	fclose(f);
-	return cut_lib(strdup(dir));
+	return strdup(dir);
       }
     }
+    fclose(f);
   }
-  fclose(f);
   snprintf(fn,
 	   64,
 	   "/proc/%u/exe",
 	   getpid());
-  lnk = malloc(1024);
+  lnk = malloc(1029); /* 1024 + 5 for "lib/" catenation */
   size = readlink(fn, lnk, 1023);
   if ( (size == 0) || (size >= 1024) ) {
     free(lnk);
@@ -355,7 +366,10 @@ get_path_from_proc_exe() {
     return NULL;
   }
   lnk[size] = '\0';
-  return cut_bin(lnk);
+  lnk = cut_bin(lnk);
+  lnk = realloc(lnk, strlen(lnk) + 5);
+  strcat(lnk, "lib/"); /* guess "lib/" as the library dir */
+  return lnk;
 }
 #endif
 
@@ -367,15 +381,45 @@ static char * get_path_from_module_filename() {
   char * path;
   char * idx;
 
-  path = malloc(4097);
+  path = malloc(4103); /* 4096+nil+6 for "/lib/" catenation */
   GetModuleFileName(NULL, path, 4096);
   idx = path + strlen(path);
   while ( (idx > path) &&
-	  (path != '\\') &&
-	  (path != '/') )
+	  (*idx != '\\') &&
+	  (*idx != '/') )
     idx--;
   *idx = '\0';
-  return cut_bin(path);
+  path = cut_bin(path);
+  path = realloc(path, strlen(path) + 6);
+  strcat(path, "/lib/"); /* guess "lib/" as the library dir */
+  return path;
+}
+#endif
+
+#if DARWIN
+static char * get_path_from_dyld_image() {
+  const char * path;
+  char * p, * s;
+  int i;
+  int c;
+
+  p = NULL;
+  c = _dyld_image_count();
+  for (i = 0; i < c; i++) {
+    if (_dyld_get_image_header(i) == &_mh_dylib_header) {
+      path = _dyld_get_image_name(i);
+      if (path != NULL && strlen(path) > 0) {
+        p = strdup(path);
+        s = p + strlen(p);
+        while ( (s > p) && (*s != '/') )
+          s--;
+        s++;
+        *s = '\0';
+      }
+      break;
+    }
+  }
+  return p;
 }
 #endif
 
@@ -408,7 +452,10 @@ get_path_from_PATH() {
       pos = strdup(pos);
       free(buf);
       free(path);
-      return cut_bin(pos);
+      pos = cut_bin(pos);
+      pos = realloc(pos, strlen(pos) + 5);
+      strcat(pos, "lib/");
+      return pos;
     }
     pos = end + 1;
   }
@@ -417,7 +464,10 @@ get_path_from_PATH() {
     pos = strdup(pos);
     free(buf);
     free(path);
-    return cut_bin(pos);
+    pos = cut_bin(pos);
+    pos = realloc(pos, strlen(pos) + 5);
+    strcat(pos, "lib/");
+    return pos;
   }
   free(buf);
   free(path);
@@ -429,8 +479,21 @@ get_path_from_ENV_PREFIX() {
   const char * p;
 
   p = getenv("LIBEXTRACTOR_PREFIX");
-  if (p != NULL)
-    return cut_bin(cut_lib(strdup(p)));
+  if (p != NULL) {
+    char * s = malloc(strlen(p) + 6);
+    if (s != NULL) {
+      int len;
+      strcpy(s, p);
+      s = cut_bin(cut_lib(s));
+      len = strlen(s);
+      s = realloc(s, len + 6);
+      if (len > 0 && s[len-1] != '/')
+        strcat(s, "/lib/");
+      else
+        strcat(s, "lib/");
+      return s;
+    }
+  }
   return NULL;
 }
 
@@ -444,6 +507,7 @@ static char * os_get_installation_path() {
   char * lpref;
   char * pexe;
   char * modu;
+  char * dima;
   char * path;
 
   lpref = get_path_from_ENV_PREFIX();
@@ -456,37 +520,49 @@ static char * os_get_installation_path() {
   modu = get_path_from_module_filename();
 #else
   modu = NULL;
+#endif
+#if DARWIN
+  dima = get_path_from_dyld_image();
+#else
+  dima = NULL;
 #endif
   path = get_path_from_PATH();
   n = 1;
   if (lpref != NULL)
-    n += strlen(lpref) + strlen("/lib/libextractor/:");
+    n += strlen(lpref) + strlen(PLUGINDIR "/:");
   if (pexe != NULL)
-    n += strlen(pexe) + strlen("/lib/libextractor/:");
+    n += strlen(pexe) + strlen(PLUGINDIR "/:");
   if (modu != NULL)
-    n += strlen(modu) + strlen("/lib/libextractor/:");
+    n += strlen(modu) + strlen(PLUGINDIR "/:");
+  if (dima != NULL)
+    n += strlen(dima) + strlen(PLUGINDIR "/:");
   if (path != NULL)
-    n += strlen(path) + strlen("/lib/libextractor/:");
+    n += strlen(path) + strlen(PLUGINDIR "/:");
   tmp = malloc(n);
   tmp[0] = '\0';
   if (lpref != NULL) {
     strcat(tmp, lpref);
-    strcat(tmp, "/lib/libextractor/:");
+    strcat(tmp, PLUGINDIR "/:");
     free(lpref);
   }
   if (pexe != NULL) {
     strcat(tmp, pexe);
-    strcat(tmp, "/lib/libextractor/:");
+    strcat(tmp, PLUGINDIR "/:");
     free(pexe);
   }
   if (modu != NULL) {
     strcat(tmp, modu);
-    strcat(tmp, "/lib/libextractor/:");
+    strcat(tmp, PLUGINDIR "/:");
     free(modu);
   }
+  if (dima != NULL) {
+    strcat(tmp, dima);
+    strcat(tmp, PLUGINDIR "/:");
+    free(dima);
+  }
   if (path != NULL) {
     strcat(tmp, path);
-    strcat(tmp, "/lib/libextractor/:");
+    strcat(tmp, PLUGINDIR "/:");
     free(path);
   }
   if (strlen(tmp) > 0)
